# History of changes

## Version qtsass v0.3.0 (2020/03/18)

### Issues Closed

* [Issue 50](https://github.com/spyder-ide/qtsass/issues/50) - Add rever to release process ([PR 51](https://github.com/spyder-ide/qtsass/pull/51) by [@goanpeca](https://github.com/goanpeca))
* [Issue 48](https://github.com/spyder-ide/qtsass/issues/48) - Move CI to github actions ([PR 49](https://github.com/spyder-ide/qtsass/pull/49) by [@goanpeca](https://github.com/goanpeca))

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 51](https://github.com/spyder-ide/qtsass/pull/51) - PR: Add rever to release process, by [@goanpeca](https://github.com/goanpeca) ([50](https://github.com/spyder-ide/qtsass/issues/50))
* [PR 49](https://github.com/spyder-ide/qtsass/pull/49) - PR: Move to github actions, by [@goanpeca](https://github.com/goanpeca) ([48](https://github.com/spyder-ide/qtsass/issues/48))

In this release 2 pull requests were closed.

## Version 0.2 (2020-02-23)

### Issues Closed

* [Issue 43](https://github.com/spyder-ide/qtsass/issues/43) - rgba function breaks on incoming 8bit ints ([PR 40](https://github.com/spyder-ide/qtsass/pull/40) by [@ewerybody](https://github.com/ewerybody))
* [Issue 42](https://github.com/spyder-ide/qtsass/issues/42) - qlineargradient x1,y1,x2,y2 values can be floats! ([PR 40](https://github.com/spyder-ide/qtsass/pull/40) by [@ewerybody](https://github.com/ewerybody))
* [Issue 41](https://github.com/spyder-ide/qtsass/issues/41) - make qtsass watchdog dependence optional

In this release 3 issues were closed.

### Pull Requests Merged

* [PR 44](https://github.com/spyder-ide/qtsass/pull/44) - Add Watcher api, by [@danbradham](https://github.com/danbradham)
* [PR 40](https://github.com/spyder-ide/qtsass/pull/40) - added support for incomplete coords and incoming %-rgba values ..., by [@ewerybody](https://github.com/ewerybody) ([43](https://github.com/spyder-ide/qtsass/issues/43), [42](https://github.com/spyder-ide/qtsass/issues/42))

In this release 2 pull requests were closed.

## Version 0.1.0 (2019-05-05)

### Issues Closed

* [Issue 21](https://github.com/spyder-ide/qtsass/issues/21) - Reorganize qtsass package
* [Issue 18](https://github.com/spyder-ide/qtsass/issues/18) - CLI - build/watch directory ([PR 23](https://github.com/spyder-ide/qtsass/pull/23) by [@danbradham](https://github.com/danbradham))
* [Issue 17](https://github.com/spyder-ide/qtsass/issues/17) - Create PyPI package ([PR 32](https://github.com/spyder-ide/qtsass/pull/32) by [@goanpeca](https://github.com/goanpeca))
* [Issue 16](https://github.com/spyder-ide/qtsass/issues/16) - Add Windows CI - Appveyor ([PR 19](https://github.com/spyder-ide/qtsass/pull/19) by [@danbradham](https://github.com/danbradham))
* [Issue 12](https://github.com/spyder-ide/qtsass/issues/12) - Move test to a tests folder ([PR 13](https://github.com/spyder-ide/qtsass/pull/13) by [@danbradham](https://github.com/danbradham))
* [Issue 11](https://github.com/spyder-ide/qtsass/issues/11) - Add badges for coverage and travis CI builds ([PR 14](https://github.com/spyder-ide/qtsass/pull/14) by [@danbradham](https://github.com/danbradham))
* [Issue 10](https://github.com/spyder-ide/qtsass/issues/10) - Add coverage to the CI tests with codecov.io ([PR 15](https://github.com/spyder-ide/qtsass/pull/15) by [@goanpeca](https://github.com/goanpeca))
* [Issue 9](https://github.com/spyder-ide/qtsass/issues/9) - Add MIT LICENSE.txt file ([PR 2](https://github.com/spyder-ide/qtsass/pull/2) by [@danbradham](https://github.com/danbradham))
* [Issue 8](https://github.com/spyder-ide/qtsass/issues/8) - Add Travis CI integration for building and running tests ([PR 2](https://github.com/spyder-ide/qtsass/pull/2) by [@danbradham](https://github.com/danbradham))
* [Issue 7](https://github.com/spyder-ide/qtsass/issues/7) - Create RELEASE.md instructions ([PR 32](https://github.com/spyder-ide/qtsass/pull/32) by [@goanpeca](https://github.com/goanpeca))
* [Issue 6](https://github.com/spyder-ide/qtsass/issues/6) - Create conda-forge package
* [Issue 5](https://github.com/spyder-ide/qtsass/issues/5) - Create a changelog ([PR 32](https://github.com/spyder-ide/qtsass/pull/32) by [@goanpeca](https://github.com/goanpeca))
* [Issue 4](https://github.com/spyder-ide/qtsass/issues/4) - Include @import support ([PR 2](https://github.com/spyder-ide/qtsass/pull/2) by [@danbradham](https://github.com/danbradham))
* [Issue 3](https://github.com/spyder-ide/qtsass/issues/3) - Make package pip installable ([PR 2](https://github.com/spyder-ide/qtsass/pull/2) by [@danbradham](https://github.com/danbradham))

In this release 14 issues were closed.

### Pull Requests Merged

* [PR 32](https://github.com/spyder-ide/qtsass/pull/32) - PR: Prepare release, by [@goanpeca](https://github.com/goanpeca) ([7](https://github.com/spyder-ide/qtsass/issues/7), [5](https://github.com/spyder-ide/qtsass/issues/5), [17](https://github.com/spyder-ide/qtsass/issues/17))
* [PR 23](https://github.com/spyder-ide/qtsass/pull/23) - PR: Add support for compiling directories of QtSass, by [@danbradham](https://github.com/danbradham) ([18](https://github.com/spyder-ide/qtsass/issues/18))
* [PR 19](https://github.com/spyder-ide/qtsass/pull/19) - PR: windows ci - appveyor, by [@danbradham](https://github.com/danbradham) ([16](https://github.com/spyder-ide/qtsass/issues/16))
* [PR 15](https://github.com/spyder-ide/qtsass/pull/15) - PR: Add code coverage, by [@goanpeca](https://github.com/goanpeca) ([10](https://github.com/spyder-ide/qtsass/issues/10))
* [PR 14](https://github.com/spyder-ide/qtsass/pull/14) - PR: Add badges, by [@danbradham](https://github.com/danbradham) ([11](https://github.com/spyder-ide/qtsass/issues/11))
* [PR 13](https://github.com/spyder-ide/qtsass/pull/13) - PR: Moved tests to qtsass/tests/, by [@danbradham](https://github.com/danbradham) ([12](https://github.com/spyder-ide/qtsass/issues/12))
* [PR 2](https://github.com/spyder-ide/qtsass/pull/2) - PR: Make project pip installable and add @import support, by [@danbradham](https://github.com/danbradham) ([9](https://github.com/spyder-ide/qtsass/issues/9), [8](https://github.com/spyder-ide/qtsass/issues/8), [4](https://github.com/spyder-ide/qtsass/issues/4), [3](https://github.com/spyder-ide/qtsass/issues/3))

In this release 7 pull requests were closed.
